# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['transactid']

package_data = \
{'': ['*']}

install_requires = \
['certvalidator>=0.11.1,<0.12.0', 'cryptography==2.7', 'protobuf==3.9.2']

setup_kwargs = {
    'name': 'transactid',
    'version': '0.1.0a3',
    'description': 'A package for working with BIP75 and BIP70 in a Python environment.',
    'long_description': 'TransactID Library Python Edition\n\nThis library is a wrapper for using [BIP70][1] and [BIP75][2]\n\nThere are three main method types that you\'ll use: create_\\*, verify_\\*, and get_\\*.\n\nThe options for each of these methods was pulled directly from the code and include type hints.  Things to keep \nin mind when going through this document:\n* Optional[] means a single item of the type of object inside the brackets is optional and not required.\n* List[type] means that you need to provide a list of items of the specified type.\n* type means the usual, provide a single item of that type.\n\n## General Usage\n\nWhen instantiating the class you\'ll need a private key PEM and optionally a certificate PEM.  Both as\nstandard str types.  Certificate will only be needed when creating signed objects.  If you aren\'t \nsigning or creating objects you won\'t need that but private key PEM is always required.\n\n    from transactid import TransactID\n    transact = TransactID(private_key_pem=private_pem, certificate_pem=cert_pem)\n\n## Invoice Request\n\nPlease refer to the [BIP75][2] documentation for detailed requirements for a InvoiceRequest.  When it comes \nto using this library to create one you\'ll need to provide the following:\n\n* amount: Optional[int]  # amount is integer-number-of-satoshis\n* pki_type: Optional[str]  # Currently only x509+sha256 and the string none are supported.\n* memo: Optional[str]\n* notification_url: Optional[str]\n\n*Note:* while everything is technically optional it\'s not recommended to leave everything blank.  See [BIP75][2] for \nfull details.\n\nCreate an object for sending like so:\n\n    serialized_invoice_request = transact.create_invoice_request(\n        amount=amount,\n        pki_type=pki_type,\n        memo=memo,\n        notification_url=notification_url\n    )\n\nThis will provide you with a serialized binary string that you can then send to someone you would like to send \nmoney to.\n\nWhen you are on the receiving end of one of those binary strings you can do the following to validate \nthe signature and parse one:\n\n    from transactid.exceptions import InvalidSignatureException\n    from transactid.exceptions import DecodeException\n\n    try:\n        transact.verify_invoice_request(serialized_invoice_request)\n    except InvalidSignatureException:\n        <let sender know the signature was invalid>\n    except DecodeException:\n        <let sendiner know there was a problem with the porotobuf object they sent over>\n    else:\n        <take data they sent you and respond appropriately>\n\nIf there are no exceptions then we were able to parse the protobuf object and validate the signature.\n\nTo access the data from the InvoiceRequest just do:\n\n    invoice_request = transact.get_verified_invoice_request()\n\nAnd that will return a dictionary with all of the fields of the InvoiceRequest and the values that were \nfilled in.\n\n## Payment Request\n\nPlease refer to the [BIP70][1] documentation for detailed requirements for a PaymentRequest. Please note we are combining\n the PaymentDetails and PaymentRequests objects for easy of use. When it comes to using this library to create \n one you\'ll need to provide the following:\n\n* time_stamp: datetime\n* outputs: List[(int, bytes)]  # int: amount, bytes: script (see [BIP70][1] details for more information on scripts)\n* memo: str\n* payment_url: str\n* merchant_data: bytes\n* expires: Optional[datetime]\n* pki_type: Optional[str]\n* network: str, defaults to "main"\n* payment_details_version: int, defaults to 1\n\nCreate an object for sending like so:\n\n    serialized_payment_request = transact.create_payment_request(\n        time_stamp=datetime.datetime.now(),\n        outputs=[(amount, script)],\n        memo=memo,\n        payment_url=payment_url,\n        merchant_data=merchant_data,\n        pki_type=pki_type\n    )\n\nThis will provide you with a serialized binary string that you can then send to someone whom you want to give you \nmoney.\n\nWhen you are on the receiving end of one of those binary strings you can do the following to validate \nthe signature and parse one:\n\n    from transactid.exceptions import InvalidSignatureException\n    from transactid.exceptions import DecodeException\n\n    try:\n        transact.verify_payment_request(serialized_invoice_request)\n    except InvalidSignatureException:\n        <let sender know the signature was invalid>\n    except DecodeException:\n        <let sendiner know there was a problem with the porotobuf object they sent over>\n    else:\n        <take data they sent you and respond appropriately>\n\nIf there are no exceptions then we were able to parse the protobuf object and validate the signature.\n\nTo access the data from the PaymentRequest just do:\n\n    payment_request = transact.get_verified_payment_request()\n\nAnd that will return a dictionary with all of the fields of the PaymentRequest and the values that were \nfilled in.\n\n## Payment\n\nPlease refer to the [BIP70][1] documentation for detailed requirements for a Payment. When it comes to using this \nlibrary to create one you\'ll need to provide the following:\n\n* transactions: List[bytes]\n* refund_to: List[(int, bytes)]  # int: amount, bytes: script (see BIP70 details for more information on scripts)\n* merchant_data: Optional[bytes]\n* memo: Optional[str]\n\nCreate an object for sending like so:\n\n    serialized_payment = transact.create_payment(\n        transactions=transactions,\n        refund_to=outputs,\n        memo=memo,\n        merchant_data=merchant_data,\n    )\n\nThis will provide you with a serialized binary string that you can then send to someone and let them know you gave \nthem money.\n\nWhen you are on the receiving end of one of those binary strings you can do the following to parse one.  \nPlease note that Payments aren\'t signed unlike the Invoice/PaymentRequest:\n\n    from transactid.exceptions import DecodeException\n\n    try:\n        transact.verify_payment_request(serialized_payment)\n    except DecodeException:\n        <let sendiner know there was a problem with the porotobuf object they sent over>\n    else:\n        <take data they sent you and respond appropriately>\n\nIf there are no exceptions then we were able to parse the protobuf object.\n\nTo access the data from the Payment just do:\n\n    payment_request = transact.get_verified_payment()\n\nAnd that will return a dictionary with all of the fields of the Payment and the values that were \nfilled in.\n\n## PaymentACK\n\nPlease refer to the [BIP70][1] documentation for detailed requirements for a PaymentACK. PaymentACKs are a bit different \nthan other things in the library.  Due to the fact that art of the PaymentACK is the Payment object you are \nacknowledging, it\'s not possible to create an ACK without first verifying a Payment.\n\n* memo: Optional[str]\n\nCreate an object for sending like so:\n\n    serialized_payment_ack = transact.create_payment_ack(memo=payment_ack_memo)\n\nThis will provide you with a serialized binary string that you can then send to someone to acknowledge that they \nsent you money.\n\nWhen you are on the receiving end of one of those binary strings you can do the following to parse one.  \nPlease note that Payments aren\'t signed unlike the Invoice/PaymentRequest:\n\n    from transactid.exceptions import DecodeException\n\n    try:\n        transact.verify_payment_ack(serialized_payment_ack)\n    except DecodeException:\n        <let sendiner know there was a problem with the porotobuf object they sent over>\n    else:\n        <take data they sent you and respond appropriately>\n\nIf there are no exceptions then we were able to parse the protobuf object.\n\nTo access the data from the PaymentACK just do:\n\n    payment_request = transact.get_verified_payment_ack()\n\nAnd that will return a dictionary with all of the fields of the PaymentACK and the values that were \nfilled in.\n\n\n[1]: https://github.com/bitcoin/bips/blob/master/bip-0070.mediawiki\n[2]: https://github.com/bitcoin/bips/blob/master/bip-0075.mediawiki\n',
    'author': 'Jeremy Kenyon',
    'author_email': 'jeremy@netki.com',
    'url': 'https://github.com/netkicorp/transactid-library-python',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6.5,<4.0.0',
}


setup(**setup_kwargs)
